{#{% if perms.bee_django_crm.add_crm_preuser_fee %}#}
    <a class="btn btn-default" href="{% url 'bee_django_crm:preuser_detail' user.userprofile.preuser.id %}">新增合同/缴费</a>
{#{% endif %}#}
{#{% if perms.bee_django_user.add_user_leave %}#}
    <a class="btn btn-default" href="{% url 'bee_django_user:leave_list' user.id %}">新增请假/延期</a>
{#{% endif %}#}
{% if perms.bee_django_track.add_track_other %}
    <a class="btn btn-default" href="{% url 'bee_django_track:record_add' user_id=user.id %}">添加其他</a>
{% endif %}